var express = require('express');
var path = require('path');
//var favicon = require('serve-favicon');
var logger = require('morgan');
var cookieParser = require('cookie-parser');
var bodyParser = require('body-parser');
var session = require('express-session');
var MemoryStore = require('memorystore')(session);
var flash = require('connect-flash');
var theme = 'default-dark';
var app = express();
//var request = require('request');
// view engine setup
app.set('views', path.join(__dirname, '../themes'));
app.set('view engine', 'pug');
app.use(logger('dev'));

app.use(bodyParser.json({ limit: '50mb' }));
app.use(
	bodyParser.urlencoded({
		extended: false,
		limit: '50mb'
	})
);
app.use(cookieParser());
app.use(express.static(path.join(__dirname, '../public'), { extensions: ['html'] }));
//app.use(express.static(path.join(__dirname, '../content')));
//app.use(express.static(path.join(__dirname, '../themes')));
app.use(
	session({
		store: new MemoryStore({
			checkPeriod: 86400000 // prune expired entries every 24h
		}),
		secret: '1KqZ18W8KskE1iSw',
		saveUninitialized: false,
		resave: false,
		cookie: {
			maxAge: 608800000
		}
	})
);
app.use(flash());
//sections
var front = require('./routes/front/index')(session);
var back = require('./routes/back/index');
var postDashboard = require('./routes/back/dash_posts');
var settingsDashboard = require('./routes/back/dash_settings');
var navDashboard = require('./routes/back/dash_nav');
//api
var postLibrary = require('./api/content/posts');
var settings = require('./api/content/settings');
var mailer = require('./api/mail/mailer');
var auth = require('./api/v1/auth');
// API PATHS

app.use('/api/post', postLibrary);
app.use('/api/settings', settings);
app.use('/api/mail', mailer);
app.use('/api/v1/auth', auth);
// PAGES
app.use('/', front);
app.use('/@/dashboard', back);
app.use('/@/dashboard/posts', postDashboard);
app.use('/@/dashboard/settings', settingsDashboard);
app.use('/@/dashboard/navigation', navDashboard);
//app.use('/mailer', mailer);
// catch 404 and forward to error handler
app.use(function(req, res, next) {
	var err = new Error('Not Found');
	err.status = 404;
	next(err);
});
// error handlers
// development error handler
// will print stacktrace
if (app.get('env') === 'development') {
	app.use(function(err, req, res) {
		res.status(err.status || 500);
		res.render(theme + '/error', {
			message: err.message,
			error: err
		});
	});
}
// production error handler
// no stacktraces leaked to user
app.use(function(err, req, res) {
	res.status(err.status || 500);
	res.render(theme + '/error', {
		message: err.message,
		error: {}
	});
});
module.exports = app;
